@@ -73,6 +73,9 @@ class AuthOpenIdHandler(object):
         self.cookie_expires = float(authopenid_conf.get('cookieexpires', 3600.0))
         self.ip_mask = authopenid_conf.get('ipmask', '255.255.255.0')
         self.cookie_secret = authopenid_conf.get('cookiesecret', 'secret')
+        # Use agent string if you are sure that your site uses single agent.
+        # E.g. SWFUpload generates different user agent string.
+        self.cookie_use_agent = bool(authopenid_conf.get('cookieuseagent', 'False'))
 
         self._get_store(authopenid_conf)
 
@@ -110,9 +113,10 @@ class AuthOpenIdHandler(object):
         mask = struct.unpack('>L', socket.inet_aton(self.ip_mask))[0]
         address = struct.unpack('>L', socket.inet_aton(address))[0]
 
-        user_string = socket.inet_ntoa(struct.pack('>L', address & mask)) + \
-                environ.get('HTTP_USER_AGENT', '') + \
-                self.cookie_secret
+        user_string = socket.inet_ntoa(struct.pack('>L', address & mask))
+        if self.cookie_use_agent:
+            user_string += environ.get('HTTP_USER_AGENT', '')
+        user_string += self.cookie_secret
         return md5.md5(user_string).hexdigest()
 
     def _check_authopenidcookie(self, environ):
